@@ -457,7 +457,7 @@ def create_select_query(self, columns, conditions, query):
     if query is None: # initial query not set so create one
         if not columns:
             columns = get_select_columns(self.config)
-        query = select(columns, bind=self.db.session.bind)
+        query = select(*columns)
 
     self._search_conditions = conditions # save for later
     # TODO: remove after debugging:
