@@ -238,7 +238,7 @@ class ExportPlugin(XmlExportBase):
     def process_tags(self, document, dvdelement, tagsquery):
         tagselem = document.createElement('Tags')
         dvdelement.appendChild(tagselem)
-        for tag in tagsquery.execute().fetchall():
+        for tag in self.db.session.execute(tagsquery).fetchall():
             value = self.convert_value(tag['name'])
             tagelem = document.createElement('Tag')
             tagselem.appendChild(tagelem)
