@@ -66,8 +66,11 @@ class GriffithSQL(object):
                 config.set('port', GriffithSQL.DEFAULT_PORTS[config.get('type', section='database')], section='database')
 
         conn_params = config.to_dict(section='database')
-        conn_params.update({'port': int(conn_params.get('port', 0)),
-                            'engine_kwargs': {'echo': False, 'convert_unicode': False}})
+        conn_params.update({
+            'port': int(conn_params.get('port', 0)),
+            # SQLAlchemy 2.0: remove deprecated convert_unicode
+            'engine_kwargs': {'echo': False},
+        })
 
         # connect to database --------------------------------------{{{
         dbinitializingsql = None
@@ -87,8 +90,9 @@ class GriffithSQL(object):
                 url = "postgresql"
             url = url + "://%(user)s:%(passwd)s@%(host)s:%(port)d/%(name)s" % conn_params
         elif config.get('type', section='database') == 'mysql':
-            conn_params['engine_kwargs']['convert_unicode'] = True
-            conn_params['engine_kwargs']['pool_recycle'] = int(config.get('pool_recycle', 3600, section='database'))
+            conn_params['engine_kwargs']['pool_recycle'] = int(
+                config.get('pool_recycle', 3600, section='database')
+            )
             url = "mysql://%(user)s:%(passwd)s@%(host)s:%(port)d/%(name)s?charset=utf8&use_unicode=0" % conn_params
         elif config.get('type', section='database') == 'mssql':
             # use_scope_identity=0 have to be set as workaround for a sqlalchemy bug
@@ -107,9 +111,11 @@ class GriffithSQL(object):
         # try to establish a db connection
         try:
             engine = create_engine(url, **conn_params['engine_kwargs'])
-            conn = engine.connect()
+            engine.connect()
             if dbinitializingsql is not None:
-                engine.execute(dbinitializingsql)
+                # SQLAlchemy 2.0: use exec_driver_sql for driver-level PRAGMA
+                with engine.begin() as conn:
+                    conn.exec_driver_sql(dbinitializingsql)
         except Exception as e:    # InvalidRequestError, ImportError
             log.info("MetaData: %s", e)
             if not fallback:
@@ -118,7 +124,7 @@ class GriffithSQL(object):
             warning("%s\n\n%s" % (_('Cannot connect to database.\nFalling back to SQLite.'), _('Please check debug output for more informations.')))
             url = "sqlite:///%s.db" % os.path.join(griffith_dir, conn_params['name'])
             engine = create_engine(url)
-            conn = engine.connect()
+            engine.connect()
 
         # scoped_session(...) is a workaround for unclosed sessions in the program
         # https://bugs.launchpad.net/griffith/+bug/574370
@@ -161,68 +167,93 @@ class GriffithSQL(object):
             del self.session
             del self.Session
             del self.engine
-        except:
+        except Exception:
             log.exception('')
 
 
 def update_whereclause(query, cond): # {{{
     if cond['loaned'] is True:
-        query = query.where(db.Movie.loaned == True)
+        query = query.where(db.Movie.loaned is True)
     if cond['loaned'] is False:
-        query = query.where(db.Movie.loaned == False)
+        query = query.where(db.Movie.loaned is False)
     if cond['seen'] is True:
-        query = query.where(db.Movie.seen == True)
+        query = query.where(db.Movie.seen is True)
     if cond['seen'] is False:
-        query = query.where(db.Movie.seen == False)
+        query = query.where(db.Movie.seen is False)
 
     if cond["collections"]:
         query = query.where(db.Movie.collection_id.in_(cond["collections"]))
     if cond["no_collections"]:
-        query = query.where(or_(~db.Movie.collection_id.in_(cond["no_collections"]), db.Movie.collection_id == None))
+        query = query.where(or_(~db.Movie.collection_id.in_(cond["no_collections"]), db.Movie.collection_id is None))
 
     if cond["volumes"]:
         query = query.where(db.Movie.volume_id.in_(cond["volumes"]))
     if cond["no_volumes"]:
-        query = query.where(or_(~db.Movie.volume_id.in_(cond["no_volumes"]), db.Movie.volume_id == None))
+        query = query.where(or_(~db.Movie.volume_id.in_(cond["no_volumes"]), db.Movie.volume_id is None))
 
     loaned_to = []
     for per_id in cond["loaned_to"]:
-        loaned_to.append(exists([db.tables.loans.c.movie_id],\
-                and_(db.Movie.movie_id == db.tables.loans.c.movie_id,
-                     db.tables.loans.c.person_id == per_id,
-                     db.tables.loans.c.return_date == None)))
+        loaned_to.append(
+            exists().where(
+                and_(
+                    db.Movie.movie_id == db.tables.loans.c.movie_id,
+                    db.tables.loans.c.person_id == per_id,
+                    db.tables.loans.c.return_date.is_(None),
+                )
+            )
+        )
     if loaned_to:
         query = query.where(or_(*loaned_to))
 
     loan_history = []
     for per_id in cond["loan_history"]:
-        loan_history.append(exists([db.tables.loans.c.movie_id],\
-                and_(db.Movie.movie_id == db.tables.loans.c.movie_id,
-                     db.tables.loans.c.person_id == per_id)))
+        loan_history.append(
+            exists().where(
+                and_(
+                    db.Movie.movie_id == db.tables.loans.c.movie_id,
+                    db.tables.loans.c.person_id == per_id,
+                )
+            )
+        )
     if loan_history:
         query = query.where(or_(*loan_history))
 
     required_tags = []
     for tag_id in cond["required_tags"]:
-        required_tags.append(exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id == db.MovieTag.movie_id,
-                 db.MovieTag.tag_id == tag_id)))
+        required_tags.append(
+            exists().where(
+                and_(
+                    db.Movie.movie_id == db.MovieTag.movie_id,
+                    db.MovieTag.tag_id == tag_id,
+                )
+            )
+        )
     if required_tags:
         query = query.where(and_(*required_tags))
 
     tags = []
     for tag_id in cond["tags"]:
-        tags.append(exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id == db.MovieTag.movie_id,
-                 db.MovieTag.tag_id == tag_id)))
+        tags.append(
+            exists().where(
+                and_(
+                    db.Movie.movie_id == db.MovieTag.movie_id,
+                    db.MovieTag.tag_id == tag_id,
+                )
+            )
+        )
     if tags:
         query = query.where(or_(*tags))
 
     no_tags = []
     for tag_id in cond["no_tags"]:
-        no_tags.append(~exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id == db.MovieTag.movie_id,
-                 db.MovieTag.tag_id == tag_id)))
+        no_tags.append(
+            ~exists().where(
+                and_(
+                    db.Movie.movie_id == db.MovieTag.movie_id,
+                    db.MovieTag.tag_id == tag_id,
+                )
+            )
+        )
     if no_tags:
         query = query.where(and_(*no_tags))
 
